@@ -4,10 +4,14 @@ import os
 import sys
 from argparse import ArgumentParser
 
+try:
+    from catkin_pkg.workspaces import get_spaces
+except ImportError as e:
+    sys.exit('ImportError: "catkin_pkg.workspaces import get_spaces" failed: %s\nMake sure that you have installed "catkin_pkg", it is up to date and on the PYTHONPATH.' % e)
 try:
     from catkin_pkg.workspaces import order_paths
 except ImportError as e:
-    sys.exit('ImportError: "from catkin_pkg.package import parse_package" failed: %s\nMake sure that you have installed "catkin_pkg", it is up to date and on the PYTHONPATH.' % e)
+    sys.exit('ImportError: "from catkin_pkg.workspaces import order_paths" failed: %s\nMake sure that you have installed "catkin_pkg", it is up to date and on the PYTHONPATH.' % e)
 
 
 def main():
@@ -18,7 +22,13 @@ def main():
     parser.add_argument('--prefixes', nargs='*', help='The semicolon-separated prefixes defining the order')
     args = parser.parse_args()
 
-    ordered_paths = order_paths(args.paths_to_order, args.prefixes)
+    # resolve the source space if any
+    spaces = []
+    for prefix in args.prefixes:
+        spaces.append(prefix)
+        spaces += get_spaces([prefix])
+
+    ordered_paths = order_paths(args.paths_to_order, spaces)
 
     # create directory if necessary
     outdir = os.path.dirname(args.outfile)
