@@ -31,7 +31,8 @@ class MockTest(AbstractCatkinWorkspaceTest):
         assert_exists(self.installdir,
                       'env.sh',
                       'setup.sh',
-                      'setup.zsh')
+                      'setup.zsh',
+                      'setup.fish')
 
     def test_linker_options_propagation(self):
         dstdir = os.path.join(self.workspacedir, 'linker_options')
@@ -43,7 +44,8 @@ class MockTest(AbstractCatkinWorkspaceTest):
         assert_exists(self.installdir,
                       'env.sh',
                       'setup.sh',
-                      'setup.zsh')
+                      'setup.zsh',
+                      'setup.fish')
 
     def test_nolang(self):
         dstdir = os.path.join(self.workspacedir, 'nolangs')
