@@ -2,5 +2,5 @@ import std_msgs.msg
 
 s = std_msgs.msg.String()
 
-print("<<< a >>>")
+print('<<< a >>>')
 print(type(s))
